Module parser

Module parser 

Structs

TextRange
WordLocation

Functions

extract_all_words
Extract all candidate words from a document, recursively following @injection.* captures in .scm query files to handle multi-language files.
get_word_from_string
Get a UTF-8 word from a string given the start and end bytes in utf16.