Structs
Functions
- extract_
all_ words - Extract all candidate words from a document, recursively following
@injection.*captures in .scm query files to handle multi-language files. - get_
word_ from_ string - Get a UTF-8 word from a string given the start and end bytes in utf16.